# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
import json
import boto3
import botocore
import logging
logger = logging.getLogger()
logger.setLevel(logging.INFO)
dynamodb = boto3.resource('dynamodb')
ddb_client = boto3.client('dynamodb')

def _write_timestamp_to_ddb2(ddb_table_name,new_timestamp_value,ddb_timestamp_field_name,lastSuccessfulRuns,database_name,table_name):     
    transact_items=[]
    for l in lastSuccessfulRuns:
        primary_key=_create_primary_key_for_ddb_record(l['tenantId'],database_name,table_name)  
        if(l["lastSuccessfulRun"]=="FIRST_RUN"):
            new_item={"N": {"S": primary_key },ddb_timestamp_field_name: {"S": new_timestamp_value}}
            put_item={"Put":{"Item":new_item,"TableName":ddb_table_name,"ConditionExpression":"attribute_not_exists(N)"}}
            transact_items.append(put_item)
        else:
            update_key={"N": {"S": primary_key }}
            update_item={"Update":{"Key":update_key,"TableName":ddb_table_name,"ConditionExpression": ddb_timestamp_field_name+" = :last_successful_run","UpdateExpression":"SET "+ddb_timestamp_field_name+" = :new_timestamp","ExpressionAttributeValues":{":new_timestamp":{"S":new_timestamp_value},":last_successful_run":{"S": l["lastSuccessfulRun"]} } }}
            transact_items.append(update_item)
    
    try: 
        response = ddb_client.transact_write_items(TransactItems=transact_items)
        logger.info(response)
        return {'statusCode':response['ResponseMetadata']['HTTPStatusCode'],"body":response}
    except botocore.exceptions.ClientError as error:
        raise(error)
def _write_timestamp_to_ddb(ddb_table_name,primary_key,timestamp_value,ddb_timestamp_field_name):
    try:
        ddb_table = dynamodb.Table(ddb_table_name)
        item={"N":primary_key,ddb_timestamp_field_name:timestamp_value}
        response = ddb_table.put_item(item)
        return {'statusCode':response['ResponseMetadata']['HTTPStatusCode'],"body":response}
    except botocore.exceptions.ClientError as error:
        return {'statusCode':error.response['ResponseMetadata']['HTTPStatusCode'],'body':error.response}
def _process_ddb_response(response,ddb_timestamp_field_name):
    if (response['statusCode']==200 and "Item" not in response['body']): 
        last_successful_run="FIRST_RUN"
    elif (response['statusCode']==200 and "Item" in response['body']):
        last_successful_run=response['body']['Item'][ddb_timestamp_field_name]['S']
    # exceptions are being raised so no need to treat the non 200 request
    return {'statusCode':response['statusCode'],'Content':last_successful_run}
def _get_latest_timestamp(ddb_table_name,primary_key):#,ddb_timestamp_field_name):
    try:
        response=ddb_client.get_item(Key={'N': {'S':primary_key}},TableName=ddb_table_name)
        return {'statusCode':response['ResponseMetadata']['HTTPStatusCode'],"body":response}
    except (ddb_client.exceptions.ResourceNotFoundException,ddb_client.exceptions.ProvisionedThroughputExceededException,ddb_client.exceptions.RequestLimitExceeded, ddb_client.exceptions.InternalServerError) as e:
        raise(e)
    except botocore.exceptions.ClientError as error:
        raise(error)
def _create_primary_key_for_ddb_record(tenant_id,database_name,table_name):
    return tenant_id+"+"+database_name+"+"+table_name

def lambda_handler(event, context):
    logger.info(event)
    activity=event['ddbDetails']['activity']
    ddb_timestamp_field_name=event['ddbDetails']['ddbTimestampFieldName']
    ddb_table_name=event['ddbDetails']['ddbTableName']
    database_name=event['sourceConfig']['databaseName']
    table_name=event['sourceConfig']['tableName']

    if activity=='get':
        tenant_id=event['tenantId']
        primary_key=_create_primary_key_for_ddb_record(tenant_id,database_name,table_name)  
        response=_get_latest_timestamp(ddb_table_name,primary_key)
        processed_response=_process_ddb_response(response,ddb_timestamp_field_name)
        return processed_response
    elif activity=='put':
        new_timestamp_value=event['ddbDetails']['workflowStartTime']
        lastSuccessfulRuns=event["body"]["Aggregates"]["lastSuccessfulRuns"]
        response=_write_timestamp_to_ddb2(ddb_table_name,new_timestamp_value,ddb_timestamp_field_name,lastSuccessfulRuns,database_name,table_name)
        return response 

