#!/bin/sh -x

# Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0

if [ "$#" != "8" ]
then
        echo "Call this script with S3_BUCKET_NAME_BLOG_ARTIFACTS AURORA_ENDPOINT_TENANT1 AURORA_ENDPOINT_TENANT2 EMR_CLUSTER_PRIVATEDNSNAME S3_BUCKET_NAME_DATA_STORAGE RDS_Master_Tenant1_Password_Label_SSM  RDS_Master_Tenant2_Password_Label_SSM AWS_REGION"
	exit 1
fi


export S3_BUCKET_NAME_BLOG_ARTIFACTS=${1}
export AURORA_ENDPOINT_TENANT1=${2}
export AURORA_ENDPOINT_TENANT2=${3}
export EMR_CLUSTER_PRIVATEDNSNAME=${4}
export S3_BUCKET_NAME_DATA_STORAGE=${5}
export SSM_PARAMETER_STORE_LABEL_MASTER_USER_PASSWORD_TENANT1=${6}
export SSM_PARAMETER_STORE_LABEL_MASTER_USER_PASSWORD_TENANT2=${7}
export AWS_REGION=${8}
# MySQL
sudo yum install -y mysql-devel
sudo yum -y install mysql

## Install mysql package in conda python3 env
source activate python3
pip install --upgrade pip 
pip install mysqlclient==1.3.12
source deactivate

# Copy sample notebooks
aws s3 cp --recursive s3://${S3_BUCKET_NAME_BLOG_ARTIFACTS}/hudi/notebooks/ /home/ec2-user/SageMaker
export NOTEBOOK_NAME=Runmev5.ipynb
# Replace tokens in notebooks
sed -i "s/###aurora_endpoint_tenant1###/${AURORA_ENDPOINT_TENANT1}/" /home/ec2-user/SageMaker/${NOTEBOOK_NAME}
sed -i "s/###aurora_endpoint_tenant2###/${AURORA_ENDPOINT_TENANT2}/" /home/ec2-user/SageMaker/${NOTEBOOK_NAME}
sed -i "s/###emr_spark_cluster_master###/${EMR_CLUSTER_PRIVATEDNSNAME}/g" /home/ec2-user/SageMaker/${NOTEBOOK_NAME} 


sed -i "s/###s3_bucket###/${S3_BUCKET_NAME_DATA_STORAGE}/g" /home/ec2-user/SageMaker/${NOTEBOOK_NAME}

# Copy SQL Script
aws s3 cp s3://${S3_BUCKET_NAME_BLOG_ARTIFACTS}/salesdb.sql /home/ec2-user/scripts/salesdb.sql

export DB_SETTINGS_TENANT1=(`aws ssm get-parameter --name  ${SSM_PARAMETER_STORE_LABEL_MASTER_USER_PASSWORD_TENANT1}  --region  ${AWS_REGION} --with-decryption --query Parameter.Value  --output text | tr '\t' ' '`)

export DB_SETTINGS_TENANT2=(`aws ssm get-parameter --name  ${SSM_PARAMETER_STORE_LABEL_MASTER_USER_PASSWORD_TENANT2}  --region  ${AWS_REGION} --with-decryption --query Parameter.Value  --output text | tr '\t' ' '`)

# Load the data into Aurora
mysql -f -u master -h ${AURORA_ENDPOINT_TENANT1}  --password=${DB_SETTINGS_TENANT1} < /home/ec2-user/scripts/salesdb.sql

# Load the data into Aurora
mysql -f -u master -h ${AURORA_ENDPOINT_TENANT2}  --password=${DB_SETTINGS_TENANT2} < /home/ec2-user/scripts/salesdb.sql


